@@ -5,7 +5,7 @@ use Test;
 use Data::Taxi;    # TESTING
 
 
-BEGIN { plan tests => 1 };
+BEGIN { plan tests => 3 };
 
 
 my ($struct, $hold);
@@ -18,15 +18,29 @@ $struct = {
 		'Robinson',
 		'VA Tech',
 	],
+	
+	titles => {
+		president => 'Idocs',
+		worker => 'Dietrick',
+	},
 };
 
+$struct->{'jobs'} = $struct->{'titles'};
 $hold = Data::Taxi::freeze($struct);
-
-# die "early exit\n";
-
 $struct = Data::Taxi::thaw($hold);
 
 if ($struct->{'schools'}->[1] eq 'Robinson')
 	{ok 1}
 else
 	{ok 0}
+
+if ($struct->{'jobs'}->{'president'} eq 'Idocs')
+	{ok 1}
+else
+	{ok 0}
+
+if ($struct->{'jobs'} eq $struct->{'titles'})
+	{ok 1}
+else
+	{ok 0}
+
